@@ -4,10 +4,20 @@ import numpy as np
 
 
 class SINrViz:
+    """Visualization package for SINr embdeddings. The goal is to visualize and interpret
+    the diemnesions of the embeddings produced."""
     def __init__(self, sinr_vectors: SINrVectors):
         self.sinr_vectors = sinr_vectors
 
     def compare_stereotypes(self, args, topk_dim=5):
+        """Make a heatmap comparing top dimensions for elements in args (words).
+
+        :param args: A list of indices (words).
+        :type args: list[int]
+        :param topk_dim: Number of top dimensions to fetch, defaults to 5
+        :type topk_dim: int, optional
+
+        """
         if len(args) == 0:
             print("No objects passed as parameters")
             return
@@ -32,7 +42,7 @@ class SINrViz:
             fig, ax = plt.subplots()
             im = ax.imshow(data)
             cbar = ax.figure.colorbar(im, ax=ax)
-            cbar.ax.set_ylabel("test", rotation=-90, va="bottom")
+            cbar.ax.set_ylabel("Strength of relatedness", rotation=-90, va="bottom")
             ax.set_xticks(np.arange(len(stereotypes)), labels=stereotypes)
             ax.set_yticks(np.arange(len(args)), labels=args)
 
